#
# spec file
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor debug%{nil}
%if "%{flavor}" != ""
%define nsuffix -%{flavor}
%endif

%define git_version %nil
Name:           dapl%{?nsuffix}
Summary:        A Library for userspace access to RDMA devices using OS Agnostic DAT APIs
License:        BSD-3-Clause OR GPL-2.0-or-later OR CPL-1.0
Group:          Productivity/Networking/System
Version:        2.1.10
Release:        7.3
Source0:        https://www.openfabrics.org/downloads/dapl/dapl-%version.tar.gz
Source1:        dapl-rpmlintrc
Source2:        baselibs.conf

Patch1:         dapl-2.0.30-dat-ia-open-hang.patch
Patch2:         dapl-define_NULL.patch
Patch3:         dapl-man_page_fixes.patch
Patch4:         dapl-fsf_address.patch
Patch5:         dapl-s390.patch
Patch6:         dapl-add-arm-platform-support.patch
Patch7:         ucm-mcm-fix-backlog-parameter-for-socket.patch
Patch8:         reproducible.patch
Patch9:         openib-add-missing-include.patch
URL:            http://www.openfabrics.org
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libibverbs-devel
BuildRequires:  librdmacm-devel
BuildRequires:  libtool

%if "%name" == "dapl"
Conflicts:      dapl-debug
%else
Conflicts:      dapl
%endif

# bug437293
%ifarch ppc64
Obsoletes:      dapl-64bit
%endif
#
Requires(post): /sbin/ldconfig
Requires(postun):/sbin/ldconfig
Requires(post): sed
Requires(post): coreutils

# libdapl*.so work like plugins, hence they do not get a separate subpackage.

%if "%{name}" == "dapl-debug"
%define lname       dapl-debug-libs
%define other_lname libdat2-2
%else
%define lname       libdat2-2
%define other_lname dapl-debug-libs
%endif

%description
Along with the OpenFabrics kernel drivers, libdat and libdapl provide
a userspace RDMA API that supports DAT 2.0 specification and IB
transport extensions for atomic operations and rdma write with
immediate data.

%package     -n %lname
Summary:        DAPL runtime libraries
Group:          System/Libraries
Conflicts:      %other_lname
Obsoletes:      dapl2 < %version
Provides:       dapl2 = %version
# Need dat.conf
Requires:       %name

%description -n %lname
libdat and libdapl provide a userspace RDMA API that supports DAT 2.0
specification and IB transport extensions for atomic operations and
rdma write with immediate data.

This package contains the runtime libraries.
%if "%{name}" == "dapl-debug"
The libraries have tracing enabled.
%endif

%package        devel
Summary:        Development files for the libdat and libdapl libraries
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       glibc-devel
%if "%name" == "dapl"
Conflicts:      dapl-debug-devel
%else
Conflicts:      dapl-devel
%endif

%description    devel
Library links and header files for the libdat and libdapl libraries.
%if "%{name}" == "dapl-debug"
The libraries have tracing enabled.
%endif

%package        utils
Summary:        Test suite for the uDAPL library
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}-%{release}
Recommends:     dapl-doc = %{version}
%if "%name" == "dapl"
Conflicts:      dapl-debug-utils
%else
Conflicts:      dapl-utils
%endif

%description utils
Test suite to validate the uDAPL library APIs.

%prep
%autosetup -p0 -n dapl-%{version}

%build
%if %suse_version == 1110
export ac_cv_suse11=yes
%endif
autoreconf -fi
%if "%name" == "dapl"
%configure --disable-static --with-pic
%else
%configure --disable-static --with-pic --enable-debug
%endif

make %{?_smp_mflags} V=1

%check
export MALLOC_CHECK_=2
make check
unset MALLOC_CHECK_

%install
make DESTDIR=%{buildroot} install

rm -f %{buildroot}%_libdir/*.la
%if "%{name}" == "dapl-debug"
rm -rf %{buildroot}%{_mandir}/man{1,5}/*
%endif
mkdir -p %{buildroot}%_sysconfdir
touch %{buildroot}%_sysconfdir/dat.conf

#Rename tests to avoid conflicts.
# dtest clashes with dateutils package
mv %{buildroot}%{_bindir}/dapltest %{buildroot}%{_bindir}/dapl-test
mv %{buildroot}%{_bindir}/dtest %{buildroot}%{_bindir}/dapl-utest
mv %{buildroot}%{_bindir}/dtestcm %{buildroot}%{_bindir}/dapl-testcm
mv %{buildroot}%{_bindir}/dtestsrq %{buildroot}%{_bindir}/dapl-testsrx
mv %{buildroot}%{_bindir}/dtestx %{buildroot}%{_bindir}/dapl-testx

%define man_regexp -e s/dapltest/dapl-test/g -e s/dtestcm/dapl-testcm/g -e s/dtestsrq/dapl-testsrq/g -e s/dtestx/dapl-testx/g -e s/dtest/dapl-utest/g

%if "%{name}" != "dapl-debug"
# Fix man pages accordingly
for manpage in dapltest dtest dtestcm dtestsrq dtestx; do
	new_name=$(echo $manpage | sed %man_regexp)
	sed %man_regexp %{buildroot}%{_mandir}/man1/$manpage.1 > %{buildroot}%{_mandir}/man1/$new_name.1
	rm %{buildroot}%{_mandir}/man1/$manpage.1
done
%endif

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%post
/sbin/ldconfig
if test -e %_sysconfdir/dat.conf; then
	sed -i -e '/ofa-v2-.* u2/d' %_sysconfdir/dat.conf
else
    touch %_sysconfdir/dat.conf
fi
cat <<EOF >>%_sysconfdir/dat.conf
ofa-v2-mlx4_0-1 u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx4_0 1" ""
ofa-v2-mlx4_0-2 u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx4_0 2" ""
ofa-v2-ib0 u2.0 nonthreadsafe default libdaplofa.so.2 dapl.2.0 "ib0 0" ""
ofa-v2-ib1 u2.0 nonthreadsafe default libdaplofa.so.2 dapl.2.0 "ib1 0" ""
ofa-v2-mthca0-1 u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mthca0 1" ""
ofa-v2-mthca0-2 u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mthca0 2" ""
ofa-v2-ipath0-1 u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "ipath0 1" ""
ofa-v2-ipath0-2 u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "ipath0 2" ""
ofa-v2-ehca0-2 u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "ehca0 1" ""
ofa-v2-iwarp u2.0 nonthreadsafe default libdaplofa.so.2 dapl.2.0 "eth2 0" ""
ofa-v2-mlx4_0-1u u2.0 nonthreadsafe default libdaploucm.so.2 dapl.2.0 "mlx4_0 1" ""
ofa-v2-mlx4_0-2u u2.0 nonthreadsafe default libdaploucm.so.2 dapl.2.0 "mlx4_0 2" ""
ofa-v2-mthca0-1u u2.0 nonthreadsafe default libdaploucm.so.2 dapl.2.0 "mthca0 1" ""
ofa-v2-mthca0-2u u2.0 nonthreadsafe default libdaploucm.so.2 dapl.2.0 "mthca0 2" ""
ofa-v2-cma-roe-eth2 u2.0 nonthreadsafe default libdaplofa.so.2 dapl.2.0 "eth2 0" ""
ofa-v2-cma-roe-eth3 u2.0 nonthreadsafe default libdaplofa.so.2 dapl.2.0 "eth3 0" ""
ofa-v2-scm-roe-mlx4_0-1 u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx4_0 1" ""
ofa-v2-scm-roe-mlx4_0-2 u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx4_0 2" ""
ofa-v2-mcm-1 u2.0 nonthreadsafe default libdaplomcm.so.2 dapl.2.0 "mlx4_0 1" ""
ofa-v2-mcm-2 u2.0 nonthreadsafe default libdaplomcm.so.2 dapl.2.0 "mlx4_0 2" ""
ofa-v2-scif0 u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "scif0 1" ""
ofa-v2-scif0-u u2.0 nonthreadsafe default libdaploucm.so.2 dapl.2.0 "scif0 1" ""
ofa-v2-mic0 u2.0 nonthreadsafe default libdaplofa.so.2 dapl.2.0 "mic0:ib 1" ""
ofa-v2-mlx4_0-1s u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx4_0 1" ""
ofa-v2-mlx4_0-2s u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx4_0 2" ""
ofa-v2-mlx4_1-1s u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx4_1 1" ""
ofa-v2-mlx4_1-2s u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx4_1 2" ""
ofa-v2-mlx4_1-1u u2.0 nonthreadsafe default libdaploucm.so.2 dapl.2.0 "mlx4_1 1" ""
ofa-v2-mlx4_1-2u u2.0 nonthreadsafe default libdaploucm.so.2 dapl.2.0 "mlx4_1 2" ""
ofa-v2-mlx4_0-1m u2.0 nonthreadsafe default libdaplomcm.so.2 dapl.2.0 "mlx4_0 1" ""
ofa-v2-mlx4_0-2m u2.0 nonthreadsafe default libdaplomcm.so.2 dapl.2.0 "mlx4_0 2" ""
ofa-v2-mlx4_1-1m u2.0 nonthreadsafe default libdaplomcm.so.2 dapl.2.0 "mlx4_1 1" ""
ofa-v2-mlx4_1-2m u2.0 nonthreadsafe default libdaplomcm.so.2 dapl.2.0 "mlx4_1 2" ""
ofa-v2-mlx5_0-1s u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx5_0 1" ""
ofa-v2-mlx5_0-2s u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx5_0 2" ""
ofa-v2-mlx5_1-1s u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx5_1 1" ""
ofa-v2-mlx5_1-2s u2.0 nonthreadsafe default libdaploscm.so.2 dapl.2.0 "mlx5_1 2" ""
ofa-v2-mlx5_0-1u u2.0 nonthreadsafe default libdaploucm.so.2 dapl.2.0 "mlx5_0 1" ""
ofa-v2-mlx5_0-2u u2.0 nonthreadsafe default libdaploucm.so.2 dapl.2.0 "mlx5_0 2" ""
ofa-v2-mlx5_1-1u u2.0 nonthreadsafe default libdaploucm.so.2 dapl.2.0 "mlx5_1 1" ""
ofa-v2-mlx5_1-2u u2.0 nonthreadsafe default libdaploucm.so.2 dapl.2.0 "mlx5_1 2" ""
ofa-v2-mlx5_0-1m u2.0 nonthreadsafe default libdaplomcm.so.2 dapl.2.0 "mlx5_0 1" ""
ofa-v2-mlx5_0-2m u2.0 nonthreadsafe default libdaplomcm.so.2 dapl.2.0 "mlx5_0 2" ""
ofa-v2-mlx5_1-1m u2.0 nonthreadsafe default libdaplomcm.so.2 dapl.2.0 "mlx5_1 1" ""
ofa-v2-mlx5_1-2m u2.0 nonthreadsafe default libdaplomcm.so.2 dapl.2.0 "mlx5_1 2" ""
EOF
#On update save configuration before uninstall of old package runs
if [ $1 -gt 0 ]; then
	cp -p %_sysconfdir/dat.conf %_sysconfdir/dat.conf.rpmtmp
fi

%posttrans
if [ -e "%_sysconfdir/dat.conf.rpmtmp" ]; then
  mv %_sysconfdir/dat.conf.rpmtmp %_sysconfdir/dat.conf
fi

%postun
/sbin/ldconfig
#remove if this isn't an update
if [ $1 -eq 0 ]; then
	if test -e %_sysconfdir/dat.conf; then
		sed -i -e '/OpenIB-.* u1/d' %_sysconfdir/dat.conf
	fi
fi

%files
%defattr(-, root, root)
%doc AUTHORS README COPYING ChangeLog LICENSE.txt LICENSE2.txt LICENSE3.txt
%_libdir/libdapl*.so.*
%config %ghost %_sysconfdir/dat.conf
%if "%{name}" != "dapl-debug"
%_mandir/man5/dat.conf.5*
%endif
%doc

%files -n %lname
%defattr(-,root,root)
%_libdir/libdat2.so.*

%files devel
%defattr(-, root, root)
%_includedir/dat2/
%_libdir/*.so

%files utils
%defattr(-,root,root,-)
%{_bindir}/*
%if "%{name}" != "dapl-debug"
%_mandir/man1/dapl-test.1*
%_mandir/man1/dapl-utest.1*
%_mandir/man1/dapl-testcm.1*
%_mandir/man1/dapl-testsrq.1*
%_mandir/man1/dapl-testx.1*
%endif

%changelog
* Thu Sep  5 2024 Nicolas Morey <nicolas.morey@suse.com>
- Add openib-add-missing-include.patch to fix compilation
  with GCC >= 14.
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Thu May  4 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Convert to proper multibuild package: the spec is already all
  done to distinguish flavors.
* Sat Jul 14 2018 bwiedemann@suse.com
- Add reproducible.patch to fix build time (boo#1047218)
* Tue May 29 2018 nmoreychaisemartin@suse.com
- Add ucm-mcm-fix-backlog-parameter-for-socket.patch to fix
  a "deadlock" that causes socket connection to timeout when
  net.ipv4.tcp_syncookies=0. (bsc#1094657)
* Thu May 24 2018 kasimir_@outlook.de
- Add patch for arm platform support
  * dapl-add-arm-platform-support.patch
* Thu Jul 20 2017 nmoreychaisemartin@suse.com
- Update to 2.1.10
  * dtest_suite: add option to pause the test.
  * dtestcm: add client retry, give server time to queue up all listens
  * dtest: Add new man pages. (dtestx dtestcm dtestsrq)
  * cma: fix open_query mode, initialize attributes
  * ucm: up level CM timer logging, increase drep time at scale
  * dtest: fix return value check on do_rdma_write_with_msg
  * dtestx: check device capabilities and do atomic tests only if supported by HW
  * common: set atomic attributes based on provider/device capabilities
  * build: dtest_suite.sh was moved to test/scripts
  * mpxyd: let TX thread sleep if no open devices are referenced
  * mcm: when mmap req from MIC return with fail stat print WARN.
  * dtest_suite: remove duplicate dtest_suite.sh
  * dtest: enable -D option (data check) to work with scif provider
  * dtest_suite: fix typo in user_string var
  * mcm: remove logs from post send speed path
  * mcm proxy: push WR from MIC to host with scif mmap memory instead of scif_send.
  * dtest: the default size in pingpong test is set to 1 byte regardless to user input.
  * dtest: cleanup 4 printfs from the middle of performance test, may reduce performance.
- Refresh patches against 2.1.10
* Mon Jun 12 2017 nmoreychaisemartin@suse.com
- Merge .changes files with SLE12-SP3 (bsc#1041579)
* Tue May 30 2017 nmoreychaisemartin@suse.com
- Add conflicts between dapl and dapl-debug packages for devel
  and utils
- Rename dapl-utils tests to avoid conflicts with other packages (dateutils)
  * dapltest => dapl-test
  * dtest    => dapl-utest
  * dtestcm  => dapl-testcm
  * dtestsrq => dapl-testsrq
  * dtestx   => dapl-testx
- Remove librdmacm and libibverbs version dependencies
* Thu May 25 2017 jengelh@inai.de
- Restore description of libdapl. Fix some grammar errors.
* Wed May 17 2017 nmoreychaisemartin@suse.com
- Disable dapl on armv7hl
* Wed Mar 29 2017 pth@suse.de
- Make dependencies on libs now coming from rdma-core versioned.
- Remove unused patch dapl-rename_dtest.patch
* Thu Mar 10 2016 pth@suse.de
- Update to 2.1.8 git version (bsc#970668).
  List of changes is too long so please see the included ChangeLog.
- Patches removed because the fixes are included upstream:
  dapl-fix_type_punning.patch
  dapl-autotools.patch
  dapl-add-s390x-platform-support.patch
  dapl-add-aarch64-platform-support.patch
  dapl-add-s390x-platform-support.patch
- Add dapl-s390.patch so that the defines are also valid for s390
* Thu Sep 10 2015 dmueller@suse.com
- add dapl-add-aarch64-platform-support.patch (fate#318444)
- revert last change
* Tue Aug 25 2015 pth@suse.de
- Exclude aarch64 as there is currently no assembler code for this
  architecture.
* Tue Aug 11 2015 pth@suse.de
- Replace dapl-s390_support.patch with
  dapl-add-s390x-platform-support.patch (bsc#934683).
- Fix library name in baselibs.conf.
- Tag baselibs.conf and dapl-rpmlintrc as source.
- libdapl*.so work like plugins, hence they do not get a separate
  subpackage. So shut up rpmlint complaining about the package
  name.
- Drop the dapl-doc sub package and move the man pages to the
  packages containing the files/programs they describe.
* Wed Feb  4 2015 dimstar@opensuse.org
- Also have dapl-utils conflict with dapl-debug-utils.
- Fix baselibs.conf to build libdat2-2-32bit.
* Mon Sep  8 2014 coolo@suse.com
- dapl-debug can't obsolete dapl or zypper will switch between the versions
  all the time. They do conflict though
* Fri Aug  8 2014 pth@suse.de
- Add dapl-rename_dtest.patch to rename dtest to dpltest because
  of name clash with dateutils.
- Also rename the man  page for dtest.
- Make dapl-devel and dapl-debug-devel obsolete each other.
* Thu Aug  7 2014 pth@suse.de
- Readd s390 support (bnc#856126).
* Mon Aug  4 2014 pth@suse.de
- Remove s390 support (bnc#856126).
* Fri Jun 27 2014 pth@suse.de
- Add baselibs.conf and dapl-rpmlintrc as source.
- Fix dapl-fix_type_punning.patch.
- Fix type punning in cm.c
* Wed Jun 25 2014 pth@suse.de
- Remove dapl-2.0.13-build_error.patch as it isn't needed anymore.
* Wed Jun 25 2014 pth@suse.de
- Provide full source URL
* Tue May 20 2014 pth@suse.de
- Fix typo in dapl_test.c.
* Thu May 15 2014 pth@suse.de
- Reenable the code for s390x also for s390.
- Adapt dapl-fix_type_punning.patch to changed code.
- Fix obsoletes entry.
- Fix type punning with memcpy instead of unions.
* Tue May 13 2014 pth@suse.de
- Update tp 2.0.42 from OFED 3.12 RC2.
  Changes since 2.0.40:
  * dapltest: increase DTO evd size to prevent CQ overflow on
    limit_rpost test.
  * Creation of reserved SP moves EP state to DAT_EP_STATE_RESERVED
    even in failure cases. Reserve EP after successfully binding the
    listening port.
  * dapl: fix string bug in dapls_dto_op_str
    This led to indexing off the end of the array and gave
    surprising results for OP_RECV_UD.
  * dapltest: change server port, from 45278 to 62000, out of
    registered IANA range.
  * dat: lower log level on load errors of provider library
  * dat: dat_ia_open should close provider after failure
  * dapltest: set default limit max to 1000
  * openib: add new provider specific attributes
  * dapltest: update scripts for regression testing purposes
  * cl.sh and srv.sh update to provide better examples and
    a methods to quickly regression test any dapltest changes.
  * dapltest: Add final send/recv "sync" for transaction tests.
  For the complete and unabbreviated Changes please see the file
  ChangeLog in the package documentation.
* Thu Feb 13 2014 pth@suse.de
- Update to 2.0.40 (fate#315488):
    dist: ib collective extension include files missing
    dapltest: the quit command is missing changes for -n option.
    Server-port was not being set properly during param init phase
    on the client side.
    dat.conf: remove v1, add Mellanox Connect-IB and Intel Xeon Phi
    MIC.
    NULL undefined on Fedora, incorrectly using kernel stddef.h
* Tue Jan 21 2014 pth@suse.de
- Add dapl-autotools.patch to make autoreconf complain less.
* Fri Jan 17 2014 pth@suse.de
- Update to 2.0.39 from 3.12 daily snapshot.
- Include dapl-s390_support.patch from IBM for s390 support.
- Remove now unneeded patches:
  dapl-2.0.13-build_error.patch
- Use script to generate spec and changes for dapl-debug from the
  dapl files.
* Wed Jan 15 2014 pth@suse.de
- Build for s390x
* Thu Sep 13 2012 pth@suse.de
- Add another filter to dapl-rpmlintrc as the packages for
  the runtime library are named differently but contain a library
  that's named the same.
* Wed Sep  5 2012 pth@suse.de
- Reinstate the arch exclusion of s390(x).
- Recompress with bzip2.
* Wed Sep  5 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Remove unjustified s390* arch exclusion
- Implement shared library policy
* Thu Aug 30 2012 pth@suse.de
- Update to OFED 1.5.4.1 (dapl unchanged).
- Rename the package with tracing enabled dapl-tracing.
- Adapt baselibs.conf to new packages and names.
- Use one .spec and .changes file and create the -tracing
  variants with pre_checkin.sh.
- Update FSF address in LICENSE3.txt.
* Tue Jul  3 2012 pth@suse.de
- Put shared libs into a versioned package.
- Fix man pages
- Add a rpmlintrc to shut up warnings that can only be solved upstream.
* Thu Jun 28 2012 pth@suse.de
- Use unions for type punning (dapl-type_punning.patch).
- Include stddef.h to get NULL defined.
- Require automake, autoconf and libtool.
- Provide obsoleted items.
* Wed May  9 2012 pth@suse.de
- Update to OFED 1.5.4
- Don't recompress the tarball.
- Remove unneeded patches and adapt the remaining ones.
* Mon Jun 20 2011 pth@suse.de
- Sed is also needed.
* Thu Jun  9 2011 pth@suse.de
- After last change dapl needs cat so add prereq (bnc#688511).
* Mon Mar  7 2011 pth@suse.de
- Don't remove the configuration for this dapl version on update
  (bnc#676731).
- Use cat instead of multiple echos.
- Include /etc/dat.conf as %%conf %%ghost.
* Fri Mar  4 2011 pth@suse.de
- Fix tmp race in post/postun (bnc#676700).
* Tue Feb  1 2011 pth@suse.de
- Incorporate fixes done for the update in SLE10:
- Split off man pages into their own sub package that can be
  required by compat-dapl.
- Fix type-punning in test app so that we don't need
  - fno-strict-aliasing allowing better code optimisation.
- Also fix type punning in other files that the newer gcc in SLE11
  detected.
- realigned-disconnect.patch fixing bnc#656702
- added cma-fix-debug-build-issue.patch fixing debug build.
* Tue Nov 23 2010 pth@suse.de
- Let the caller detect EINTR (bnc#655518).
* Mon Oct 25 2010 jjolly@novell.com
- Update to v2.0.30 from OFED 1.5.2
- Update to include more lines for dat.conf
- Patch to remove extra rdma_destroy_id() (bnc#647915)
* Tue Dec  8 2009 ro@suse.de
- fix build on ia64: help configure dectecting suse_version
* Thu Dec  3 2009 jjolly@suse.de
- Update to v2.0.19 from OFED 1.4.2
* Thu Dec 11 2008 jjolly@suse.de
- Updated to v2.0.15 from OFED 1.4 GA
  - dapltest: transaction test moves to cleanup stage before
    rdma_read processing is complete
  - Change SR to include sysconfdir.
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Nov  6 2008 ihno@suse.de
- adding baselibs.conf
* Tue Nov  4 2008 ro@suse.de
- fix build on ia64 (same as in compat-dapl)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Mon Oct 27 2008 jjolly@suse.de
- Updated to v2.0.14 from OFED 1.4 rc3
* Mon Oct 20 2008 ihno@suse.de
- Excludearch for s390 s390x
* Fri Sep 12 2008 jjolly@suse.de
- Updated to v2.0.13 from OFED 1.4 RC1 and changed from dapl2 to dapl
* Mon Apr 28 2008 crrodriguez@suse.de
- do not build unusable static libraries
- fix -devel package requires
* Mon Mar  3 2008 jjolly@suse.de
- Initial submission of dapl v2.0.7 from OFED 1.3 GA release
